@@ -1,22 +1,14 @@
-#!/usr/bin/env python
-# -*- coding: utf8 -*-
-
-try:
-    from cdecimal import Decimal, InvalidOperation
-except ImportError:  # pragma: no cover
-    from decimal import Decimal, InvalidOperation
-
 import warnings
+from decimal import Decimal, InvalidOperation
 
-import six
 from babel.core import Locale
 
 from agate.data_types.base import DataType
 from agate.exceptions import CastError
 
-#: A list of currency symbols sourced from `Xe <http://www.xe.com/symbols.php>`_.
-DEFAULT_CURRENCY_SYMBOLS = [u'؋', u'$', u'ƒ', u'៛', u'¥', u'₡', u'₱', u'£', u'€', u'¢', u'﷼', u'₪', u'₩', u'₭', u'₮',
-                            u'₦', u'฿', u'₤', u'₫']
+#: A list of currency symbols sourced from `Xe <https://www.xe.com/symbols/>`_.
+DEFAULT_CURRENCY_SYMBOLS = ['؋', '$', 'ƒ', '៛', '¥', '₡', '₱', '£', '€', '¢', '﷼', '₪', '₩', '₭', '₮',
+                            '₦', '฿', '₤', '₫']
 
 POSITIVE = Decimal('1')
 NEGATIVE = Decimal('-1')
@@ -40,7 +32,7 @@ class Number(DataType):
     """
     def __init__(self, locale='en_US', group_symbol=None, decimal_symbol=None,
                  currency_symbols=DEFAULT_CURRENCY_SYMBOLS, **kwargs):
-        super(Number, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
         self.locale = Locale.parse(locale)
 
@@ -51,8 +43,11 @@ class Number(DataType):
         with warnings.catch_warnings():
             warnings.simplefilter("ignore")
 
-            self.group_symbol = group_symbol or self.locale.number_symbols.get('group', ',')
-            self.decimal_symbol = decimal_symbol or self.locale.number_symbols.get('decimal', '.')
+            # Babel 2.14 support.
+            # https://babel.pocoo.org/en/latest/changelog.html#possibly-backwards-incompatible-changes
+            number_symbols = self.locale.number_symbols.get('latn', self.locale.number_symbols)
+            self.group_symbol = group_symbol or number_symbols.get('group', ',')
+            self.decimal_symbol = decimal_symbol or number_symbols.get('decimal', '.')
 
     def cast(self, d):
         """
@@ -68,15 +63,13 @@ class Number(DataType):
 
         if t is int:
             return Decimal(d)
-        elif six.PY2 and t is long:  # noqa: F821
-            return Decimal(d)
-        elif t is float:
+        if t is float:
             return Decimal(repr(d))
-        elif d is False:
+        if d is False:
             return Decimal(0)
-        elif d is True:
+        if d is True:
             return Decimal(1)
-        elif not isinstance(d, six.string_types):
+        if not isinstance(d, str):
             raise CastError('Can not parse value "%s" as Decimal.' % d)
 
         d = d.strip()
