@@ -1,10 +1,6 @@
-#!/usr/bin/env python
-# pylint: disable=W0212
-
 import math
 import sys
 
-import six
 from babel.numbers import format_decimal
 
 from agate import config, utils
@@ -47,6 +43,8 @@ def print_html(self, max_rows=20, max_columns=6, output=sys.stdout, max_column_w
         max_precision = float('inf')
 
     ellipsis = config.get_option('ellipsis_chars')
+    truncation = config.get_option('text_truncation_chars')
+    len_truncation = len(truncation)
     locale = locale or config.get_option('default_locale')
 
     rows_truncated = max_rows < len(self._rows)
@@ -94,10 +92,10 @@ def print_html(self, max_rows=20, max_columns=6, output=sys.stdout, max_column_w
                     locale=locale
                 )
             else:
-                v = six.text_type(v)
+                v = str(v)
 
             if max_column_width is not None and len(v) > max_column_width:
-                v = '%s...' % v[:max_column_width - 3]
+                v = '%s%s' % (v[:max_column_width - len_truncation], truncation)
 
             formatted_row.append(v)
 
