@@ -1,9 +1,4 @@
-#!/usr/bin/env python
-
-try:
-    import unittest2 as unittest
-except ImportError:
-    import unittest
+import unittest
 
 from agate import csv, fixed
 
